@@ -3,11 +3,7 @@ import { platformBrowserDynamic } from "@angular/platform-browser-dynamic";
 
 import { AppModule } from "./app.module";
 import { environment } from "./environments/environment";
-import { VortexService } from "@synerty/vortexjs";
-
-if (environment.production) {
-    enableProdMode();
-}
+import { Payload, PayloadDelegateWeb, VortexService } from "@synerty/vortexjs";
 
 const protocol = location.protocol.toLowerCase() == "https:" ? "wss" : "ws";
 VortexService.setVortexUrl(
@@ -15,4 +11,9 @@ VortexService.setVortexUrl(
 );
 VortexService.setVortexClientName("peek-admin-app");
 
+Payload.setWorkerDelegate(new PayloadDelegateWeb());
+if (environment.production) {
+    enableProdMode();
+}
+
 platformBrowserDynamic().bootstrapModule(AppModule);
